# Conveyor Belt

A command line interface for the CONVEYOR laboratory information management system (LIMS) by the [Sheffield Bioinformatics Core Facility](https://sbc.shef.ac.uk/) and [The University of Sheffield IT Services](https://www.sheffield.ac.uk/it-services/research).

